# SCOS Save Utility for Python 3

[![Upload Python Package](https://github.com/SCOS-Apps/Save-Utility/actions/workflows/python-publish.yml/badge.svg)](https://github.com/SCOS-Apps/Save-Utility/actions/workflows/python-publish.yml)

## What is this?

This utility is used for enabling access to `.ini` files to get a save like experience.

Using this is easy and fast, that even somebody who doesn't know Python really well can use this.
